@@ -2,12 +2,15 @@ __all__ = [
     "configure_models",
     "get_event_store",
     "Event",
+    "EventStore",
     "get_outbox",
     "Repository",
     "Aggregate",
     "Metadata",
     "Context",
     "NO_VERSIONING",
+    "Projector",
+    "Subscription",
 ]
 
 from typing import Callable, Type
@@ -23,7 +26,10 @@ from event_sourcery.interfaces.event import TEvent as EventProtocol
 from event_sourcery.interfaces.outbox_storage_strategy import OutboxStorageStrategy
 from event_sourcery.interfaces.subscriber import Subscriber
 from event_sourcery.outbox import Outbox
+from event_sourcery.projector import Projector
 from event_sourcery.repository import Repository
+from event_sourcery.subscription import Subscription
+from event_sourcery.types.stream_id import StreamName
 from event_sourcery.versioning import NO_VERSIONING
 from event_sourcery_pydantic.serde import PydanticSerde
 from event_sourcery_sqlalchemy.models import configure_models
@@ -51,7 +57,9 @@ def get_event_store(
     )
 
 
-def get_outbox(session: Session, publisher: Callable[[Metadata], None]) -> Outbox:
+def get_outbox(
+    session: Session, publisher: Callable[[Metadata, StreamName | None], None]
+) -> Outbox:
     return Outbox(
         serde=PydanticSerde(),
         storage_strategy=SqlAlchemyOutboxStorageStrategy(session),
