@@ -1,17 +1,21 @@
 from functools import singledispatchmethod
-from typing import Iterator, Sequence, Type, TypeVar, cast
+from typing import Iterator, Sequence, Tuple, Type, TypeVar, cast
 
 from event_sourcery.after_commit_subscriber import AfterCommit
 from event_sourcery.dto import RawEvent
 from event_sourcery.event_registry import EventRegistry
-from event_sourcery.exceptions import Misconfiguration, NoEventsToAppend
+from event_sourcery.exceptions import (
+    EitherStreamIdOrStreamNameIsRequired,
+    Misconfiguration,
+    NoEventsToAppend,
+)
 from event_sourcery.interfaces.base_event import Event
 from event_sourcery.interfaces.event import Metadata, TEvent
 from event_sourcery.interfaces.outbox_storage_strategy import OutboxStorageStrategy
 from event_sourcery.interfaces.serde import Serde
 from event_sourcery.interfaces.storage_strategy import StorageStrategy
 from event_sourcery.interfaces.subscriber import Subscriber
-from event_sourcery.types.stream_id import StreamId
+from event_sourcery.types.stream_id import StreamId, StreamName
 from event_sourcery.versioning import NO_VERSIONING, ExplicitVersioning, Versioning
 
 TAggregate = TypeVar("TAggregate")
@@ -48,32 +52,46 @@ class EventStore:
         self._subscriptions = subscriptions
 
     def load_stream(
-        self, stream_id: StreamId, start: int | None = None, stop: int | None = None
+        self,
+        stream_id: StreamId | None = None,
+        stream_name: str | None = None,
+        start: int | None = None,
+        stop: int | None = None,
     ) -> Sequence[Metadata]:
-        events = self._storage_strategy.fetch_events(stream_id, start=start, stop=stop)
+        events = self._storage_strategy.fetch_events(
+            stream_id, stream_name, start=start, stop=stop
+        )
         return self._deserialize_events(events)
 
     @singledispatchmethod
     def append(
         self,
         *events: Metadata,
-        stream_id: StreamId,
+        stream_id: StreamId | None = None,
+        stream_name: str | None = None,
         expected_version: int | Versioning = 0,
     ) -> None:
         self._append(
-            stream_id=stream_id, events=events, expected_version=expected_version
+            stream_id=stream_id,
+            stream_name=stream_name,
+            events=events,
+            expected_version=expected_version,
         )
 
     @append.register
     def _append_events(
         self,
         *events: Event,
-        stream_id: StreamId,
+        stream_id: StreamId | None = None,
+        stream_name: str | None = None,
         expected_version: int | Versioning = 0,
     ) -> None:
         wrapped_events = self._wrap_events(expected_version, events)
         self.append(
-            *wrapped_events, stream_id=stream_id, expected_version=expected_version
+            *wrapped_events,
+            stream_id=stream_id,
+            stream_name=stream_name,
+            expected_version=expected_version,
         )
 
     @singledispatchmethod
@@ -97,15 +115,21 @@ class EventStore:
     def publish(
         self,
         *events: Metadata,
-        stream_id: StreamId,
+        stream_id: StreamId | None = None,
+        stream_name: str | None = None,
         expected_version: int | Versioning = 0,
     ) -> None:
-        serialized_events = self._append(
-            stream_id=stream_id, events=events, expected_version=expected_version
+        serialized_events, actual_stream_name = self._append(
+            stream_id=stream_id,
+            stream_name=stream_name,
+            events=events,
+            expected_version=expected_version,
         )
 
         self._notify(events)
-        self._outbox_storage_strategy.put_into_outbox(serialized_events)
+        self._outbox_storage_strategy.put_into_outbox(
+            serialized_events, actual_stream_name
+        )
 
     def _notify(self, events: Sequence[Metadata]) -> None:
         for event in events:
@@ -123,23 +147,31 @@ class EventStore:
     def _publish_events(
         self,
         *events: Event,
-        stream_id: StreamId,
+        stream_id: StreamId | None = None,
+        stream_name: str | None = None,
         expected_version: int | Versioning = 0,
     ) -> None:
         wrapped_events = self._wrap_events(expected_version, events)
         self.publish(
-            *wrapped_events, stream_id=stream_id, expected_version=expected_version
+            *wrapped_events,
+            stream_id=stream_id,
+            stream_name=stream_name,
+            expected_version=expected_version,
         )
 
     def _append(
         self,
-        stream_id: StreamId,
+        stream_id: StreamId | None,
+        stream_name: str | None,
         events: Sequence[Metadata],
         expected_version: int | Versioning,
-    ) -> list[RawEvent]:
+    ) -> Tuple[list[RawEvent], StreamName | None]:
         if not events:
             raise NoEventsToAppend
 
+        if stream_id is None and stream_name is None:
+            raise EitherStreamIdOrStreamNameIsRequired()
+
         new_version = events[-1].version
         versioning: Versioning
         if expected_version is not NO_VERSIONING:
@@ -150,16 +182,30 @@ class EventStore:
         else:
             versioning = NO_VERSIONING
 
-        self._storage_strategy.ensure_stream(
+        stream_id, actual_stream_name = self._storage_strategy.ensure_stream(
             stream_id=stream_id,
+            stream_name=stream_name,
             versioning=versioning,
         )
         serialized_events = self._serialize_events(events, stream_id)
         self._storage_strategy.insert_events(serialized_events)
-        return serialized_events
+        return serialized_events, actual_stream_name
 
-    def iter(self, *streams_ids: StreamId) -> Iterator[Metadata]:
-        events_iterator = self._storage_strategy.iter(*streams_ids)
+    def iter(
+        self,
+        streams_ids: list[StreamId] | None = None,
+        events: list[Type[Event]] | None = None,
+    ) -> Iterator[Metadata]:
+        if streams_ids is None:
+            streams_ids = []
+
+        if events is None:
+            events = []
+
+        events_names = [self._event_registry.name_for_type(event) for event in events]
+        events_iterator = self._storage_strategy.iter(
+            streams_ids=streams_ids, events_names=events_names
+        )
         for event in events_iterator:
             yield self._serde.deserialize(
                 event, self._event_registry.type_for_name(event["name"])
