@@ -2,17 +2,22 @@ import abc
 from typing import Iterator, Tuple
 
 from event_sourcery.dto import RawEvent
+from event_sourcery.types.stream_id import StreamName
 
 EntryId = int
 
 
 class OutboxStorageStrategy(abc.ABC):
     @abc.abstractmethod
-    def put_into_outbox(self, events: list[RawEvent]) -> None:
+    def put_into_outbox(
+        self, events: list[RawEvent], stream_name: StreamName | None
+    ) -> None:
         pass
 
     @abc.abstractmethod
-    def outbox_entries(self, limit: int) -> Iterator[Tuple[EntryId, RawEvent]]:
+    def outbox_entries(
+        self, limit: int
+    ) -> Iterator[Tuple[EntryId, RawEvent, StreamName | None]]:
         pass
 
     @abc.abstractmethod
